@@ -1,14 +1,177 @@
-#' palr: colours for data
-#'
-#' @docType package
-#' @name palr
-NULL
+
+
 
 hexalpha <- function(a) {
   as.hexmode(round(255 * a))
 }
 
 
+.ace_colmap <- function() {
+structure(list(V1 = c(0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0.002, 0.004, 0.0061, 0.0081, 0.0101, 0.0121, 0.0141, 
+0.0162, 0.0182, 0.0202, 0.0222, 0.0242, 0.0263, 0.0283, 0.0303, 
+0.0323, 0.0343, 0.0364, 0.0384, 0.0404, 0.0424, 0.0444, 0.0465, 
+0.0485, 0.0505, 0.0525, 0.0545, 0.0566, 0.0586, 0.0606, 0.0626, 
+0.0646, 0.0667, 0.0687, 0.0707, 0.0727, 0.0747, 0.0768, 0.0788, 
+0.0808, 0.0828, 0.0848, 0.0869, 0.0889, 0.0909, 0.0929, 0.0949, 
+0.097, 0.099, 0.101, 0.103, 0.1051, 0.1071, 0.1091, 0.1111, 0.1131, 
+0.1152, 0.1172, 0.1192, 0.1212, 0.1232, 0.1253, 0.1273, 0.1293, 
+0.1313, 0.1333, 0.1354, 0.1374, 0.1394, 0.1414, 0.1434, 0.1455, 
+0.1475, 0.1495, 0.1515, 0.1535, 0.1556, 0.1576, 0.1596, 0.1616, 
+0.1636, 0.1657, 0.1677, 0.1697, 0.1717, 0.1737, 0.1758, 0.1778, 
+0.1798, 0.1818, 0.1838, 0.1859, 0.1879, 0.1899, 0.1919, 0.1939, 
+0.196, 0.198, 0.2, 0.2, 0.2081, 0.2162, 0.2242, 0.2323, 0.2404, 
+0.2485, 0.2566, 0.2646, 0.2727, 0.2808, 0.2889, 0.297, 0.3051, 
+0.3131, 0.3212, 0.3293, 0.3374, 0.3455, 0.3535, 0.3616, 0.3697, 
+0.3778, 0.3859, 0.3939, 0.402, 0.4101, 0.4182, 0.4263, 0.4343, 
+0.4424, 0.4505, 0.4586, 0.4667, 0.4747, 0.4828, 0.4909, 0.499, 
+0.5071, 0.5152, 0.5232, 0.5313, 0.5394, 0.5475, 0.5556, 0.5636, 
+0.5717, 0.5798, 0.5879, 0.596, 0.604, 0.6121, 0.6202, 0.6283, 
+0.6364, 0.6444, 0.6525, 0.6606, 0.6687, 0.6768, 0.6848, 0.6929, 
+0.701, 0.7091, 0.7172, 0.7253, 0.7333, 0.7414, 0.7495, 0.7576, 
+0.7657, 0.7737, 0.7818, 0.7899, 0.798, 0.8061, 0.8141, 0.8222, 
+0.8303, 0.8384, 0.8465, 0.8545, 0.8626, 0.8707, 0.8788, 0.8869, 
+0.8949, 0.903, 0.9111, 0.9192, 0.9273, 0.9354, 0.9434, 0.9515, 
+0.9596, 0.9677, 0.9758, 0.9838, 0.9919, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0.996, 0.9919, 0.9879, 0.9838, 
+0.9798, 0.9758, 0.9717, 0.9677, 0.9636, 0.9596, 0.9556, 0.9515, 
+0.9475, 0.9434, 0.9394, 0.9354, 0.9313, 0.9273, 0.9232, 0.9192, 
+0.9152, 0.9111, 0.9071, 0.903, 0.899, 0.8949, 0.8909, 0.8869, 
+0.8828, 0.8788, 0.8747, 0.8707, 0.8667, 0.8626, 0.8586, 0.8545, 
+0.8505, 0.8465, 0.8424, 0.8384, 0.8343, 0.8303, 0.8263, 0.8222, 
+0.8182, 0.8141, 0.8101, 0.8061, 0.802, 0.798, 0.7939, 0.7899, 
+0.7859, 0.7818, 0.7778, 0.7737, 0.7697, 0.7657, 0.7616, 0.7576, 
+0.7535, 0.7495, 0.7455, 0.7414, 0.7374, 0.7333, 0.7293, 0.7253, 
+0.7212, 0.7172, 0.7131, 0.7091, 0.7051, 0.701, 0.697, 0.6929, 
+0.6889, 0.6848, 0.6808, 0.6768, 0.6727, 0.6687, 0.6646, 0.6606, 
+0.6566, 0.6525, 0.6485, 0.6444, 0.6404, 0.6364, 0.6323, 0.6283, 
+0.6242, 0.6202, 0.6162, 0.6121, 0.6081, 0.604, 0.6), V2 = c(0, 
+0.004, 0.0081, 0.0121, 0.0162, 0.0202, 0.0242, 0.0283, 0.0323, 
+0.0364, 0.0404, 0.0444, 0.0485, 0.0525, 0.0566, 0.0606, 0.0646, 
+0.0687, 0.0727, 0.0768, 0.0808, 0.0848, 0.0889, 0.0929, 0.097, 
+0.101, 0.1051, 0.1091, 0.1131, 0.1172, 0.1212, 0.1253, 0.1293, 
+0.1333, 0.1374, 0.1414, 0.1455, 0.1495, 0.1535, 0.1576, 0.1616, 
+0.1657, 0.1697, 0.1737, 0.1778, 0.1818, 0.1859, 0.1899, 0.1939, 
+0.198, 0.202, 0.2061, 0.2101, 0.2141, 0.2182, 0.2222, 0.2263, 
+0.2303, 0.2343, 0.2384, 0.2424, 0.2465, 0.2505, 0.2545, 0.2586, 
+0.2626, 0.2667, 0.2707, 0.2747, 0.2788, 0.2828, 0.2869, 0.2909, 
+0.2949, 0.299, 0.303, 0.3071, 0.3111, 0.3152, 0.3192, 0.3232, 
+0.3273, 0.3313, 0.3354, 0.3394, 0.3434, 0.3475, 0.3515, 0.3556, 
+0.3596, 0.3636, 0.3677, 0.3717, 0.3758, 0.3798, 0.3838, 0.3879, 
+0.3919, 0.396, 0.4, 0.4, 0.4061, 0.4121, 0.4182, 0.4242, 0.4303, 
+0.4364, 0.4424, 0.4485, 0.4545, 0.4606, 0.4667, 0.4727, 0.4788, 
+0.4848, 0.4909, 0.497, 0.503, 0.5091, 0.5152, 0.5212, 0.5273, 
+0.5333, 0.5394, 0.5455, 0.5515, 0.5576, 0.5636, 0.5697, 0.5758, 
+0.5818, 0.5879, 0.5939, 0.6, 0.6061, 0.6121, 0.6182, 0.6242, 
+0.6303, 0.6364, 0.6424, 0.6485, 0.6545, 0.6606, 0.6667, 0.6727, 
+0.6788, 0.6848, 0.6909, 0.697, 0.703, 0.7091, 0.7152, 0.7212, 
+0.7273, 0.7333, 0.7394, 0.7455, 0.7515, 0.7576, 0.7636, 0.7697, 
+0.7758, 0.7818, 0.7879, 0.7939, 0.8, 0.8061, 0.8121, 0.8182, 
+0.8242, 0.8303, 0.8364, 0.8424, 0.8485, 0.8545, 0.8606, 0.8667, 
+0.8727, 0.8788, 0.8848, 0.8909, 0.897, 0.903, 0.9091, 0.9152, 
+0.9212, 0.9273, 0.9333, 0.9394, 0.9455, 0.9515, 0.9576, 0.9636, 
+0.9697, 0.9758, 0.9818, 0.9879, 0.9939, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 
+1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 0.9939, 0.9879, 0.9818, 0.9758, 
+0.9697, 0.9636, 0.9576, 0.9515, 0.9455, 0.9394, 0.9333, 0.9273, 
+0.9212, 0.9152, 0.9091, 0.903, 0.897, 0.8909, 0.8848, 0.8788, 
+0.8727, 0.8667, 0.8606, 0.8545, 0.8485, 0.8424, 0.8364, 0.8303, 
+0.8242, 0.8182, 0.8121, 0.8061, 0.8, 0.7939, 0.7879, 0.7818, 
+0.7758, 0.7697, 0.7636, 0.7576, 0.7515, 0.7455, 0.7394, 0.7333, 
+0.7273, 0.7212, 0.7152, 0.7091, 0.703, 0.697, 0.6909, 0.6848, 
+0.6788, 0.6727, 0.6667, 0.6606, 0.6545, 0.6485, 0.6424, 0.6364, 
+0.6303, 0.6242, 0.6182, 0.6121, 0.6061, 0.6, 0.5939, 0.5879, 
+0.5818, 0.5758, 0.5697, 0.5636, 0.5576, 0.5515, 0.5455, 0.5394, 
+0.5333, 0.5273, 0.5212, 0.5152, 0.5091, 0.503, 0.497, 0.4909, 
+0.4848, 0.4788, 0.4727, 0.4667, 0.4606, 0.4545, 0.4485, 0.4424, 
+0.4364, 0.4303, 0.4242, 0.4182, 0.4121, 0.4061, 0.4, 0.4, 0.396, 
+0.3919, 0.3879, 0.3838, 0.3798, 0.3758, 0.3717, 0.3677, 0.3636, 
+0.3596, 0.3556, 0.3515, 0.3475, 0.3434, 0.3394, 0.3354, 0.3313, 
+0.3273, 0.3232, 0.3192, 0.3152, 0.3111, 0.3071, 0.303, 0.299, 
+0.2949, 0.2909, 0.2869, 0.2828, 0.2788, 0.2747, 0.2707, 0.2667, 
+0.2626, 0.2586, 0.2545, 0.2505, 0.2465, 0.2424, 0.2384, 0.2343, 
+0.2303, 0.2263, 0.2222, 0.2182, 0.2141, 0.2101, 0.2061, 0.202, 
+0.198, 0.1939, 0.1899, 0.1859, 0.1818, 0.1778, 0.1737, 0.1697, 
+0.1657, 0.1616, 0.1576, 0.1535, 0.1495, 0.1455, 0.1414, 0.1374, 
+0.1333, 0.1293, 0.1253, 0.1212, 0.1172, 0.1131, 0.1091, 0.1051, 
+0.101, 0.097, 0.0929, 0.0889, 0.0848, 0.0808, 0.0768, 0.0727, 
+0.0687, 0.0646, 0.0606, 0.0566, 0.0525, 0.0485, 0.0444, 0.0404, 
+0.0364, 0.0323, 0.0283, 0.0242, 0.0202, 0.0162, 0.0121, 0.0081, 
+0.004, 0), V3 = c(0.2, 0.2081, 0.2162, 0.2242, 0.2323, 0.2404, 
+0.2485, 0.2566, 0.2646, 0.2727, 0.2808, 0.2889, 0.297, 0.3051, 
+0.3131, 0.3212, 0.3293, 0.3374, 0.3455, 0.3535, 0.3616, 0.3697, 
+0.3778, 0.3859, 0.3939, 0.402, 0.4101, 0.4182, 0.4263, 0.4343, 
+0.4424, 0.4505, 0.4586, 0.4667, 0.4747, 0.4828, 0.4909, 0.499, 
+0.5071, 0.5152, 0.5232, 0.5313, 0.5394, 0.5475, 0.5556, 0.5636, 
+0.5717, 0.5798, 0.5879, 0.596, 0.604, 0.6121, 0.6202, 0.6283, 
+0.6364, 0.6444, 0.6525, 0.6606, 0.6687, 0.6768, 0.6848, 0.6929, 
+0.701, 0.7091, 0.7172, 0.7253, 0.7333, 0.7414, 0.7495, 0.7576, 
+0.7657, 0.7737, 0.7818, 0.7899, 0.798, 0.8061, 0.8141, 0.8222, 
+0.8303, 0.8384, 0.8465, 0.8545, 0.8626, 0.8707, 0.8788, 0.8869, 
+0.8949, 0.903, 0.9111, 0.9192, 0.9273, 0.9354, 0.9434, 0.9515, 
+0.9596, 0.9677, 0.9758, 0.9838, 0.9919, 1, 1, 0.998, 0.996, 0.9939, 
+0.9919, 0.9899, 0.9879, 0.9859, 0.9838, 0.9818, 0.9798, 0.9778, 
+0.9758, 0.9737, 0.9717, 0.9697, 0.9677, 0.9657, 0.9636, 0.9616, 
+0.9596, 0.9576, 0.9556, 0.9535, 0.9515, 0.9495, 0.9475, 0.9455, 
+0.9434, 0.9414, 0.9394, 0.9374, 0.9354, 0.9333, 0.9313, 0.9293, 
+0.9273, 0.9253, 0.9232, 0.9212, 0.9192, 0.9172, 0.9152, 0.9131, 
+0.9111, 0.9091, 0.9071, 0.9051, 0.903, 0.901, 0.899, 0.897, 0.8949, 
+0.8929, 0.8909, 0.8889, 0.8869, 0.8848, 0.8828, 0.8808, 0.8788, 
+0.8768, 0.8747, 0.8727, 0.8707, 0.8687, 0.8667, 0.8646, 0.8626, 
+0.8606, 0.8586, 0.8566, 0.8545, 0.8525, 0.8505, 0.8485, 0.8465, 
+0.8444, 0.8424, 0.8404, 0.8384, 0.8364, 0.8343, 0.8323, 0.8303, 
+0.8283, 0.8263, 0.8242, 0.8222, 0.8202, 0.8182, 0.8162, 0.8141, 
+0.8121, 0.8101, 0.8081, 0.8061, 0.804, 0.802, 0.8, 0.8, 0.7919, 
+0.7838, 0.7758, 0.7677, 0.7596, 0.7515, 0.7434, 0.7354, 0.7273, 
+0.7192, 0.7111, 0.703, 0.6949, 0.6869, 0.6788, 0.6707, 0.6626, 
+0.6545, 0.6465, 0.6384, 0.6303, 0.6222, 0.6141, 0.6061, 0.598, 
+0.5899, 0.5818, 0.5737, 0.5657, 0.5576, 0.5495, 0.5414, 0.5333, 
+0.5253, 0.5172, 0.5091, 0.501, 0.4929, 0.4848, 0.4768, 0.4687, 
+0.4606, 0.4525, 0.4444, 0.4364, 0.4283, 0.4202, 0.4121, 0.404, 
+0.396, 0.3879, 0.3798, 0.3717, 0.3636, 0.3556, 0.3475, 0.3394, 
+0.3313, 0.3232, 0.3152, 0.3071, 0.299, 0.2909, 0.2828, 0.2747, 
+0.2667, 0.2586, 0.2505, 0.2424, 0.2343, 0.2263, 0.2182, 0.2101, 
+0.202, 0.1939, 0.1859, 0.1778, 0.1697, 0.1616, 0.1535, 0.1455, 
+0.1374, 0.1293, 0.1212, 0.1131, 0.1051, 0.097, 0.0889, 0.0808, 
+0.0727, 0.0646, 0.0566, 0.0485, 0.0404, 0.0323, 0.0242, 0.0162, 
+0.0081, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 
+0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0)), .Names = c("V1", 
+"V2", "V3"), class = "data.frame", row.names = c(NA, -500L))
+
+}
+
+
+# #' palette for chl to match ACE/Matlab maps
+# chlPal_AA <- function() {
+# jet.colors <-
+#      colorRampPalette(c("#00007F", "blue", "#007FFF", "cyan",
+#                                               "#7FFF7F", "yellow", "#FF7F00", "red", "#7F0000"), alpha = TRUE)
+# 
+#   cols <- gsub("FF$", "CC", jet.colors(100))
+#   brks <- c(seq(0, 2.5, length = length(cols) + 1))
+# 
+# 
+# }
+
 #' Colour to hex conversion. 
 #' 
 #' Create colours from colour names in one easy step. 
@@ -25,7 +188,7 @@ hexalpha <- function(a) {
 #' col2hex(c("#FFFFFF", "#123456FF"), alpha = 0.1)
 col2hex <- function(x, alpha = 1) {
   m <- rbind(col2rgb(x)/255,hexalpha(alpha)/255) 
-    apply(m, 2, function(x) do.call(rgb, as.list(x)))
+  rgb(m[1,], m[2,], m[3,], m[4,])
 }
 ## http://www.iup.uni-bremen.de/seaice/amsr/README_GEOTIFF.txt
 ##The colortable is adapted from the NIC colortable used for sea ice data (http://www.natice.noaa.gov):
@@ -101,20 +264,29 @@ col2hex <- function(x, alpha = 1) {
     "#000000", "#000000", "#000000", "#000000", "#000000", "#646464", 
     "#000000", "#000000", "#000000", "#000000")
 }
-##' Sea ice colours
-##' 
-##' Colours for sea ice. 
-##' 
-##' The palette functions operate in 3 modes: 
-##' 1) n colours - Pal(6) - returns 6 colours from the palette
-##' 2) data      - Pal(c(10, 50, 100)) - return colours for 3 ice concentrations
-##' 3) palette   - Pal(palette = TRUE) - return the full palette and breaks
-##' @param x a vector of data values or a single num (n)
-##' @param palette logical, if \code{TRUE} return a list with matching colours and values
-##' @param alpha value in 0,1 to specify opacity
-##' @references Derived from \url{http://www.iup.uni-bremen.de/seaice/amsr/}.
-##' @return colours, palette, or function, see Details
-##' @export
+#' Sea ice colours
+#' 
+#' Colours for sea ice. 
+#' 
+#' The palette functions operate in 3 modes: 
+#' 1) n colours - Pal(6) - returns 6 colours from the palette
+#' 2) data      - Pal(c(10, 50, 100)) - return colours for 3 ice concentrations
+#' 3) palette   - Pal(palette = TRUE) - return the full palette and breaks
+#' @param x a vector of data values or a single num (n)
+#' @param palette logical, if \code{TRUE} return a list with matching colours and values
+#' @param alpha value in 0,1 to specify opacity
+#' @references Derived from \url{http://www.iup.uni-bremen.de/seaice/amsr/}.
+#' @return colours, palette, or function, see Details
+#' @export
+#' @examples 
+#' \dontrun{
+#' library(raster)
+#' r <- raster(system.file("extdata", "nt_20140320_f17_v01_s.bin", package = "graticule") )
+#' icp <- icePal(palette = TRUE)
+#' ## The AMSR colours
+#' plot(r, col = icp$col, zlim = range(icp$breaks), 
+#' main = sprintf("NSIDC ice \\% %s", format(getZ(r))))
+#' }
 icePal <- function(x, palette = FALSE, alpha = 1) {
   
   cols <- head(.amsrecols(), 201)
@@ -137,15 +309,20 @@ icePal <- function(x, palette = FALSE, alpha = 1) {
 
 
 
-##' SST colours
-##'
-##' @title SST colours
-##' @param x a vector of data values or a single number
-##' @param palette logical, if \code{TRUE} return a list with matching colours and values
-##' @param alpha value in 0,1 to specify opacity
-##' @references Derived from \url{http://oceancolor.gsfc.nasa.gov/DOCS/palette_sst.txt}.
-##' @return colours, palette, or function, see Details
-##' @export
+#' SST colours
+#'
+#' @title SST colours
+#' @param x a vector of data values or a single number
+#' @param palette logical, if \code{TRUE} return a list with matching colours and values
+#' @param alpha value in 0,1 to specify opacity
+#' @references Derived from \url{http://oceancolor.gsfc.nasa.gov/DOCS/palette_sst.txt}.
+#' @return colours, palette, or function, see Details
+#' @export
+#' @examples 
+#' library(raster)
+#' data(oisst)
+#' sstcols <- sstPal(palette = TRUE)
+#' plot(oisst, col = sstcols$col, zlim = range(sstcols$breaks))
 sstPal <- function(x, palette = FALSE, alpha = 1) {
   ##pal <- read.table("http://oceancolor.gsfc.nasa.gov/DOCS/palette_sst.txt", header = TRUE, colClasses = "integer", comment.char = "")
   ##cols <- rgb(pal[,2], pal[,3], pal[,4], maxColorValue = 255)
@@ -213,40 +390,40 @@ sstPal <- function(x, palette = FALSE, alpha = 1) {
 
 
 
-##' Ocean colour palette for chlorophyll-a.
-##'
-##' Flexible control of the chlorophyll-a palette. If \code{x} is a
-##' single number, the function returns that many colours evenly
-##' spaced from the palette. If \code{x} is a vector of multiple
-##' values the palette is queried for colours matching those values,
-##' and these are returned. If \code{x} is missing and \code{palette}
-##' is \code{FALSE} then a function is returned that will generate n
-##' evenly spaced colours from the palette, as per
-##' \code{\link{colorRampPalette}}.
-##' @title Ocean colour colours for chlorophyll-a.
-##' @param x a vector of data values or a single number
-##' @param palette logical, if \code{TRUE} return a list with matching colours and values
-##' @param alpha value in 0,1 to specify opacity
-##' @references Derived from \url{http://oceancolor.gsfc.nasa.gov/DOCS/palette_chl_etc.txt}.
-##' @return colours, palette, or function, see Details
-##' @export
-##' @examples
-##' \dontrun{
-##' chl <- raadtools::readchla(xylim = c(100, 110, -50, -40))
-##' ## just get a small number of evenly space colours
-##' plot(chl, col = chlPal(10))
-##' ## store the full palette and work with values and colours
-##' pal <- chlPal()
-##' ## the standard full palette
-##' plot(chl, breaks = pal$breaks, col = pal$cols)
-##' ## a custom set of values with matching colours
-##' plot(chl, col = chlPal(pal$breaks[seq(1, length(pal$breaks), length = 10)]))
-##' ## any number of colours stored as a function
-##' myfun <- chlPal()
-##' plot(chl, col = myfun(18))
-##' ## just n colours
-##' plot(chl, col = chlPal(18))
-##' }
+#' Ocean colour palette for chlorophyll-a.
+#'
+#' Flexible control of the chlorophyll-a palette. If \code{x} is a
+#' single number, the function returns that many colours evenly
+#' spaced from the palette. If \code{x} is a vector of multiple
+#' values the palette is queried for colours matching those values,
+#' and these are returned. If \code{x} is missing and \code{palette}
+#' is \code{FALSE} then a function is returned that will generate n
+#' evenly spaced colours from the palette, as per
+#' \code{\link{colorRampPalette}}.
+#' @title Ocean colour colours for chlorophyll-a.
+#' @param x a vector of data values or a single number
+#' @param palette logical, if \code{TRUE} return a list with matching colours and values
+#' @param alpha value in 0,1 to specify opacity
+#' @references Derived from \url{http://oceancolor.gsfc.nasa.gov/DOCS/palette_chl_etc.txt}.
+#' @return colours, palette, or function, see Details
+#' @export
+#' @examples
+#' \dontrun{
+#' chl <- raadtools::readchla(xylim = c(100, 110, -50, -40))
+#' ## just get a small number of evenly space colours
+#' plot(chl, col = chlPal(10))
+#' ## store the full palette and work with values and colours
+#' pal <- chlPal()
+#' ## the standard full palette
+#' plot(chl, breaks = pal$breaks, col = pal$cols)
+#' ## a custom set of values with matching colours
+#' plot(chl, col = chlPal(pal$breaks[seq(1, length(pal$breaks), length = 10)]))
+#' ## any number of colours stored as a function
+#' myfun <- chlPal()
+#' plot(chl, col = myfun(18))
+#' ## just n colours
+#' plot(chl, col = chlPal(18))
+#' }
 chlPal <- function(x, palette = FALSE, alpha = 1) {
   
   ##pal <- read.table("http://oceancolor.gsfc.nasa.gov/DOCS/palette_chl_etc.txt", header = TRUE, colClasses = "integer", comment.char = "")
@@ -317,30 +494,30 @@ chlPal <- function(x, palette = FALSE, alpha = 1) {
 
 
 
-# ##' Colours for data
-# ##'
-# ##' Data levels and colour palettes
-# ##' @author Michael D. Sumner \email{michael.sumner@@aad.gov.au}
-# ##'
-# ##' Maintainer: Michael D. Sumner \email{michael.sumner@@aad.gov.au}
-# ##'
-# ##' @name palr
-# ##' @docType package
-# ##' @keywords package
+# #' Colours for data
+# #'
+# #' Data levels and colour palettes
+# #' @author Michael D. Sumner \email{michael.sumner@@aad.gov.au}
+# #'
+# #' Maintainer: Michael D. Sumner \email{michael.sumner@@aad.gov.au}
+# #'
+# #' @name palr
+# #' @docType package
+# #' @keywords package
 # NULL
 # 
-# ##' Colours for data
-# ##'
-# ##' Colour palette for data
-# ##' @title Palette builder
-# ##' @param x number of colours to return, or vector of breaks to
-# ##' return colours for
-# ##' @param pal name of the palette to use
-# ##' @param breaks return break values as well as colours?
-# ##' @return colours in hex format and data values
-# ##' @examples
-# ##' cols <- palbuilder(10)
-# ##' @export
+# #' Colours for data
+# #'
+# #' Colour palette for data
+# #' @title Palette builder
+# #' @param x number of colours to return, or vector of breaks to
+# #' return colours for
+# #' @param pal name of the palette to use
+# #' @param breaks return break values as well as colours?
+# #' @return colours in hex format and data values
+# #' @examples
+# #' cols <- palbuilder(10)
+# #' @export
 # palbuilder <- function(x, pal = "chl_standard", breaks = FALSE) {
 #     .pal <- .load_pal(pal)
 #     if (length(x) == 1L) {
@@ -355,24 +532,24 @@ chlPal <- function(x, palette = FALSE, alpha = 1) {
 #     cols
 # }
 # 
-# ##' @rdname palbuilder
-# ##' @export
+# #' @rdname palbuilder
+# #' @export
 # palbreaks <- function(pal) {
 #     .pal <- .load_pal(pal)
 #     .pal$breaks
 # }
-# ##' Colours for data
-# ##'
-# ##' Named palette functions.
-# ##' \code{modis} and \code{seawifs} are aliases.
-# ##' @title Named palettes
-# ##' @aliases seawifs
-# ##' @param x number of colours to return, or vector of breaks to
-# ##' return colours for
-# ##' @param breaks logical, if \code{TRUE} return the breaks values
-# ##' @return colours in hex format, break values if \code{x} is missing
-# ##' and breaks is TRUE, or a list of colours and breaks if
-# ##' @export
+# #' Colours for data
+# #'
+# #' Named palette functions.
+# #' \code{modis} and \code{seawifs} are aliases.
+# #' @title Named palettes
+# #' @aliases seawifs
+# #' @param x number of colours to return, or vector of breaks to
+# #' return colours for
+# #' @param breaks logical, if \code{TRUE} return the breaks values
+# #' @return colours in hex format, break values if \code{x} is missing
+# #' and breaks is TRUE, or a list of colours and breaks if
+# #' @export
 # modis <- function(x, breaks = FALSE) {
 #     palbuilder(x = x, pal = "modis", breaks = breaks)
 # }
@@ -486,35 +663,35 @@ chlPal <- function(x, palette = FALSE, alpha = 1) {
 # 
 
 
-# ##'
-# ##' Colours and breaks for palettes 
-# ##'
-# ##' See Examples for how some of these data were collected from a SEADAS (7) installation.
-# ##' @name colours
-# ##' @references \url{http://seadas.gsfc.nasa.gov/}
-# ##' @docType data
-# ##' @title Data values and matching colour display palette
-# ##' @format A list of lists, each consisting of vectors \code{col} and \code{breaks}.
-# ##' @keywords data
-# ##' @examples
-# ##' names(colours)
-# ##'
-# ##' \dontrun{
-# ##' read.cpd <- function(x) {
-# ##'        txt <- readLines(x)
-# ##'        cold <- read.table(text = sapply(strsplit(grep("^color", txt, value = TRUE), "="), "[", 2), sep = ",")
-# ##'        cold$value <- as.numeric(sapply(strsplit(grep("^sample", txt, value = TRUE), "="), "[", 2))
-# ##'        list(breaks = cold$value, col = rgb(cold[,1], cold[,2], cold[, 3], max = 255))
-# ##'}
-# ##'
-# ##'up <- file.path("C:/Users/michae_sum", ".seadas", "beam-ui", "auxdata", "color-palettes")
-# ##'fs <- list.files(up, pattern = "cpd$")
-# ##'
-# ##'seadas.colours <- vector("list", length(fs))
-# ##'names(seadas.colours) <- gsub(".cpd$", "", fs)
-# ##'for (i in seq_along(fs)) {
-# ##'    seadas.colours[[i]] <- read.cpd(file.path(up, fs[i]))
-# ##'}
-# ##' ## save(seadas.colours, file = "seadas.colours.rda")
-# ##' }
+# #'
+# #' Colours and breaks for palettes 
+# #'
+# #' See Examples for how some of these data were collected from a SEADAS (7) installation.
+# #' @name colours
+# #' @references \url{http://seadas.gsfc.nasa.gov/}
+# #' @docType data
+# #' @title Data values and matching colour display palette
+# #' @format A list of lists, each consisting of vectors \code{col} and \code{breaks}.
+# #' @keywords data
+# #' @examples
+# #' names(colours)
+# #'
+# #' \dontrun{
+# #' read.cpd <- function(x) {
+# #'        txt <- readLines(x)
+# #'        cold <- read.table(text = sapply(strsplit(grep("^color", txt, value = TRUE), "="), "[", 2), sep = ",")
+# #'        cold$value <- as.numeric(sapply(strsplit(grep("^sample", txt, value = TRUE), "="), "[", 2))
+# #'        list(breaks = cold$value, col = rgb(cold[,1], cold[,2], cold[, 3], max = 255))
+# #'}
+# #'
+# #'up <- file.path("C:/Users/michae_sum", ".seadas", "beam-ui", "auxdata", "color-palettes")
+# #'fs <- list.files(up, pattern = "cpd$")
+# #'
+# #'seadas.colours <- vector("list", length(fs))
+# #'names(seadas.colours) <- gsub(".cpd$", "", fs)
+# #'for (i in seq_along(fs)) {
+# #'    seadas.colours[[i]] <- read.cpd(file.path(up, fs[i]))
+# #'}
+# #' ## save(seadas.colours, file = "seadas.colours.rda")
+# #' }
 # NULL
